@@ -6,10 +6,8 @@ from networkx import algorithms
 try:
     import tkinter as tk
 except ImportError as error:
-    print(error)
-    print("Your Python installation may not be configured for TKinter, a dependency of Satyrn")
-    print("Visit https://tkdocs.com/tutorial/install.html to install TKinter")
-    exit(1)
+    raise ImportError(_("Your Python installation may not be configured for TKinter, a dependency of Satyrn\n" +
+                        "Visit https://tkdocs.com/tutorial/install.html to install TKinter")) from error
 
 import threading
 
@@ -102,7 +100,6 @@ class Cell:
         ex_vars_copy = exec_vars.copy()
 
         try:
-            print("<" + self.name + ">")
             exec(self.content, ex_vars_copy)
         except Exception as exception:
             print("Exception occurred in cell " + self.name)
@@ -163,8 +160,7 @@ class Graph:
     def add_cell(self, new_cell: Cell):
         """:param new_cell: Cell object to be added to graph."""
         if new_cell.name in list(self.names_to_indeces.keys()):
-            print(new_cell.name)
-            print("All cells must have unique names")
+            print("Cannot use name {}, all cells must have unique names".format(new_cell.name))
             return
         else:
             self.graph.add_node(len(self.graph.nodes), data=new_cell, name=new_cell.name)
@@ -205,8 +201,6 @@ class Graph:
             return "Cycles are not allowed"
         else:
             self.graph.add_edge(idx1, idx2)
-            print(self.get_layer(self.get_lookup_table()[idx1]))
-            print(self.get_layer(self.get_lookup_table()[idx2]))
             return "Safe"
 
     def sever_cells(self, idx1, idx2):
@@ -354,19 +348,17 @@ class Graph:
         if len(self.get_all_cells_edges()[0]) == 0:
             return
 
-        std_file_out = "<root>"
-
         self.executing = True
 
         root_cell = self.get_cell("", 0)
 
         root = threading.Thread(target=root_cell.execute)
 
+        std_file_out = root_cell.name
+
         root.start()
         root.join()
 
-        time.sleep(.05)
-
         std_file_out += root_cell.output
 
         n_ = self.graph.neighbors(0)
@@ -385,6 +377,7 @@ class Graph:
 
                 new_neighbors.extend([i for i in self.graph.neighbors(n)])
 
+            # TODO : check if this is broken
             for proc in processes:
                 proc.join()
 
@@ -465,13 +458,11 @@ class Graph:
         cells = [self.get_cell(cn) for cn in cell_names]
 
         for c in cells:
-            print(nb)
             if c.content_type == "python":
                 nb.cells.append(new_code_cell(c.content, metadata={'name': c.name}))
             else:
                 nb.cells.append(new_markdown_cell(c.content, metadata={'name': c.name}))
 
-        print(json_writer.writes(nb))
         return json_writer.writes(nb)
 
 
